import * as i0 from '@angular/core';
import { EventEmitter, Directive, Input, Output, HostBinding, HostListener, inject, PLATFORM_ID, Injectable, Inject, Pipe, SecurityContext, InjectionToken, NgModule } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { isPlatformBrowser, DOCUMENT } from '@angular/common';
import { BehaviorSubject, Subject } from 'rxjs';
import { isObject, uniqBy } from 'lodash';
import * as clean from 'obj-clean';
import * as i1 from '@angular/platform-browser';

class FocusClickDirective {
    constructor() {
        // Allow the button to ignore click events when set to true
        this.disabled = false;
        // Allow the function passed by the host to be executed
        // when the emit() method gets called
        /**
         * This directive replaces the default `click` directive and allows the user to execute
         * the `click` event by clicking the mouse **and**  by using the `enter` key on focus.
         *
         * A tabindex of `0` gets added to the host.
         *
         * @memberof FocusClickDirective
         */
        this.focusClick = new EventEmitter();
        // Make every tag that uses this directive by default tabbable
        this.tabIndex = 0;
    }
    // Add eventhandler to the click event
    isClicked(event) {
        if (!this.disabled) {
            this.focusClick.emit(event);
        }
    }
    // Add eventhandler to keydown event When enter is pressed and the event
    // isn't blocked, execute the click function of the host
    isEntered() {
        if (!this.disabled) {
            this.focusClick.emit();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: FocusClickDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.0.4", type: FocusClickDirective, selector: "[focusClick]", inputs: { disabled: "disabled" }, outputs: { focusClick: "focusClick" }, host: { listeners: { "click": "isClicked($event)", "keydown.enter": "isEntered()" }, properties: { "attr.tabindex": "this.tabIndex" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: FocusClickDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[focusClick]',
                }]
        }], propDecorators: { disabled: [{
                type: Input
            }], focusClick: [{
                type: Output
            }], tabIndex: [{
                type: HostBinding,
                args: ['attr.tabindex']
            }], isClicked: [{
                type: HostListener,
                args: ['click', ['$event']]
            }], isEntered: [{
                type: HostListener,
                args: ['keydown.enter']
            }] } });

const Directives = [FocusClickDirective];

const getQueryParams = () => {
    return inject(ActivatedRoute).queryParams;
};

// @dynamic
class WindowService {
    /* eslint-enable */
    constructor(document, 
    // tslint:disable-next-line: ban-types
    platformId) {
        this.document = document;
        this.platformId = platformId;
        /* eslint-disable @typescript-eslint/member-ordering */
        this.widthSubject$ = new BehaviorSubject(1200);
        this.scrollingUpSubject$ = new BehaviorSubject(true);
        this.currentScrollPositionSubject$ = new BehaviorSubject(0);
        /**
         * Observable to get the window-width, defaults to 1200 when no window is defined
         */
        this.width$ = this.widthSubject$.asObservable();
        /**
         * Observable to track when the scroll has ended
         */
        this.scrollingUp$ = this.scrollingUpSubject$.asObservable();
        /**
         * Observable of the current scroll position after the scroll has ended
         */
        this.currentScrollPosition$ = this.currentScrollPositionSubject$.asObservable();
        /**
         * Current scroll position after the scroll has ended
         */
        this.currentScrollPosition = 0;
        if (this.isBrowser() && this.hasDocument()) {
            this.window = this.document.defaultView;
            this.document.addEventListener('scroll', this.handleContentScroll.bind(this));
            this.widthSubject$.next(this.window.innerWidth);
            this.window.addEventListener('resize', () => {
                if (this.window.innerWidth && this.widthSubject$.getValue()) {
                    this.widthSubject$.next(this.window.innerWidth);
                }
            });
        }
    }
    /**
     * Scrolls to the provided position of the page
     *
     * @param offset - Offset to which we want to scroll, scrolls to top when no offset is provided
     */
    scrollTo(offset = 0) {
        if (!this.window) {
            return;
        }
        this.window.scrollTo(0, offset);
    }
    /**
     * Returns whether there is a document present
     */
    hasDocument() {
        return !!this.document;
    }
    /**
     * Returns whether the current platform is a browser
     */
    isBrowser() {
        return isPlatformBrowser(this.platformId);
    }
    handleContentScroll() {
        if (window.pageYOffset > this.currentScrollPosition) {
            this.scrollingUpSubject$.next(false);
        }
        else {
            this.scrollingUpSubject$.next(true);
        }
        this.currentScrollPosition = window.pageYOffset < 0 ? 0 : window.pageYOffset;
        this.currentScrollPositionSubject$.next(this.currentScrollPosition);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: WindowService, deps: [{ token: DOCUMENT }, { token: PLATFORM_ID }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: WindowService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: WindowService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [PLATFORM_ID]
                }] }] });

/*
 * This windowMock constant return an object with a selected spy.
 * The reason why the spy is not provided by default is for this mock
 * to work on both Jest and Jasmine based test-suites.
 *
 * example:
 * windowMock(jasmine.createSpy());
 * */
const windowMock = (spy) => ({
    addEventListener: spy,
    defaultView: {
        scrollTo: () => null,
        innerWidth: 720,
        addEventListener: spy,
    },
});
/*
 * Provide a spy for your testing framework because the windowMock requires it.
 *
 * The reason why the spy is not provided by default is for this mock
 * to work on both Jest and Jasmine based test-suites.
 *
 * example:
 * windowServiceMock(jasmine.createSpy(), 1440);
 * */
const windowServiceMock = (spy, width = 1200) => ({
    width: new BehaviorSubject(width),
    window: windowMock(spy),
    scrollTo: () => null,
    hasDocument: () => true,
    isBrowser: () => true,
});

class SubscriptionService {
    constructor() {
        this.destroyed$ = new Subject();
    }
    ngOnDestroy() {
        this.destroyed$.next(true);
        this.destroyed$.complete();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: SubscriptionService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: SubscriptionService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: SubscriptionService, decorators: [{
            type: Injectable
        }] });

class BtwPipe {
    /**
     * Converts a BTW number to the correct format
     *
     * @param value - The value we wish to convert
     */
    transform(value) {
        if (!value) {
            // Denis: if the value is falsy, return it without transform.
            return value;
        }
        const addCharAtIndex = (original, char, index) => {
            return original.slice(0, index) + char + original.slice(index);
        };
        // Iben: Convert to string if it's a number
        value = value.toString();
        if (value.replace(/\./g, '').length === 9) {
            value = '0' + value;
        }
        // Iben: Format: xxxx.xxx.xxx
        if (value.charAt(4) !== '.') {
            value = addCharAtIndex(value, '.', 4);
        }
        if (value.charAt(8) !== '.') {
            value = addCharAtIndex(value, '.', 8);
        }
        return value;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: BtwPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: BtwPipe, name: "btw" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: BtwPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'btw',
                }]
        }] });

class CleanArrayPipe {
    /**
     * Removes all falsy values from the provided array.
     *
     * @param value The values that need to be stripped of falsy values.
     * @param exceptions The falsy values that may be included in the filtered array.
     * @returns The filtered array.
     */
    transform(value, exceptions = []) {
        if (!exceptions.length) {
            return value.filter(Boolean);
        }
        return value.filter((entry) => Boolean(entry) || exceptions.includes(entry));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: CleanArrayPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: CleanArrayPipe, name: "cleanArray" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: CleanArrayPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'cleanArray',
                }]
        }] });

class EntriesPipe {
    /**
     * Transforms a record into a [key, value] array
     *
     * @param value - The provided record
     */
    transform(value) {
        // Iben: If there's no value or the value is not an object, we return an empty array to prevent frontend breaking
        if (!value || !isObject(value) || Array.isArray(value)) {
            return [];
        }
        // Iben: Transform the record to a [key,value] array
        return Array.from(Object.entries(value));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: EntriesPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: EntriesPipe, name: "entries" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: EntriesPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'entries',
                }]
        }] });

class HasObserversPipe {
    transform(output) {
        return output && output.observers.length > 0;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: HasObserversPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: HasObserversPipe, name: "hasObservers" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: HasObserversPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'hasObservers',
                }]
        }] });

class HasValuesPipe {
    /**
     * Checks whether an object has values
     *
     * @param value - The provided value
     */
    transform(value) {
        // Iben: If the value is not an object, return valse
        if (!value || !isObject(value) || Array.isArray(value)) {
            return false;
        }
        // Iben: Return when the object has values
        return Object.keys(clean(value)).length > 0;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: HasValuesPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: HasValuesPipe, name: "hasValues" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: HasValuesPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'hasValues',
                }]
        }] });

class HighlightPipe {
    /**
     * Highlights the provided substring of a test with the chosen dom element
     *
     * @param value - The full text with the part we wish to highlight
     * @param highlight - The part of the text we wish to highlight
     * @param domElement - The dom-element we wish to use to highlight, by default this is a `mark` element
     */
    transform(value, highlight, domElement = 'mark') {
        // Iben: Early exit if there's no value or the value is not a string
        if (!value || typeof value !== 'string') {
            return value;
        }
        // Iben: Match the highlight and replace it with the wrapped element
        const regexp = new RegExp(`(${highlight})`, 'i');
        return value.replace(regexp, `<${domElement}>$1</${domElement}>`);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: HighlightPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: HighlightPipe, name: "highlight" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: HighlightPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'highlight',
                }]
        }] });

class IbanPipe {
    transform(value = '') {
        value = value.replace(/\s/g, ''); // replace all spaces
        let reformat = value.replace(/(.{4})/g, function (match) {
            return match + ' '; // reformat into groups of 4 succeeded with a space
        });
        reformat = reformat.trim(); // remove trailing space
        return reformat;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: IbanPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: IbanPipe, name: "IBAN" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: IbanPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'IBAN',
                }]
        }] });

// Iben: This implementation is from https://github.com/nglrx/pipes/blob/master/packages/pipes/src/lib/array/join/join.pipe.ts
// The package is no longer supported and is not compatible with more recent versions of Angular
class JoinPipe {
    /**
     * Transforms an array to a joined string
     *
     * @param values - An array of values
     * @param separator - A separator we wish to use
     */
    transform(values, separator) {
        return values && values.join(separator);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: JoinPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: JoinPipe, name: "join" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: JoinPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'join',
                }]
        }] });

class LimitToPipe {
    /**
     * Limits an array to a specific value
     *
     * @param value - The provided array
     * @param limitedTo - The number to which we want to limit the array
     */
    transform(value, limitedTo) {
        // Iben: If no value is provided or the value is not an array, we early exit
        if (!value || !Array.isArray(value)) {
            return [];
        }
        // Iben: Slice the array based on the provided limit
        return [...value].slice(0, limitedTo);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: LimitToPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: LimitToPipe, name: "limitTo" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: LimitToPipe, decorators: [{
            type: Pipe,
            args: [{ name: 'limitTo' }]
        }] });

class SafeHtmlPipe {
    constructor(sanitized) {
        this.sanitized = sanitized;
    }
    /**
     * Maps a provided string value to a sanitized string
     *
     * @param value - A provided string with HTML items
     */
    transform(value) {
        // Iben: Early exit in case the value is not a string
        if (!value || typeof value !== 'string') {
            return '';
        }
        // Iben: Sanitize the string
        return this.sanitized.sanitize(SecurityContext.HTML, value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: SafeHtmlPipe, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: SafeHtmlPipe, name: "safeHtml" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: SafeHtmlPipe, decorators: [{
            type: Pipe,
            args: [{ name: 'safeHtml' }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }] });

class StripHtmlPipe {
    transform(value) {
        return value
            ? String(value)
                .replace(/<[^>]+>/gm, '')
                .replace('&nbsp;', '')
                .replace(/(\r\n|\n|\r)/gm, '')
            : '';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: StripHtmlPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: StripHtmlPipe, name: "stripHtml" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: StripHtmlPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'stripHtml',
                }]
        }] });

/**
 * A pipe to pass a transformer function to. By using this setup, we can use functions without causing rerender issues
 */
class TransformPipe {
    /**
     * Transforms a value based on a provided transform function
     *
     * @param value - The provided value we wish to transform
     * @param transformer - A provided transform function
     */
    transform(value, transformer) {
        // Iben: If no transformer is passed, we return the original value
        if (!transformer) {
            return value;
        }
        // Iben: Transform the value and return
        return transformer(value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: TransformPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: TransformPipe, name: "transform" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: TransformPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'transform',
                }]
        }] });

class TruncateTextPipe {
    transform(value, limit = 75) {
        return value.length > limit ? value.substring(0, limit) + '...' : value;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: TruncateTextPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: TruncateTextPipe, name: "truncateText" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: TruncateTextPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'truncateText',
                }]
        }] });

const WITH_ROUTER_LINKS_CONFIG = new InjectionToken('withRouterLinksConfig');

/**
 * An additional pipe to convert anchors to router-links
 */
class WithRouterLinkPipe {
    constructor(config, sanitizer) {
        this.config = config;
        this.sanitizer = sanitizer;
    }
    /**
     * transform
     *
     * The transform method loop through the linkReferences and find/replace matching
     * references within the given value (string) with the provided web component (global/local config).
     *
     * @param value
     * @param linkReferences
     */
    transform(value, linkReferences = []) {
        // Denis: Check if the provided value is a string,
        // if not, the DOMParser would fail, so return the value as given.
        if (typeof value !== 'string') {
            return value;
        }
        // Denis: set up a new instance of the DOMParser and parse the value as text/html.
        // This will return a Document which we can work with to find/replace elements.
        const parser = new DOMParser();
        const body = parser.parseFromString(value, 'text/html');
        // Denis: loop over each reference within the linkReferences.
        // The argument defaults to an empty array, if no linkReferences are provided,
        // it will loop over an empty array.
        linkReferences.forEach(({ dataLinkId, link, replaceElementSelector, toAttribute }) => {
            // Denis: construct the selector string
            const selector = `a[${this.config.dataLinkIdAttributeName}="${dataLinkId}"]`;
            // Denis: select the palceholder element within the parsed Document.
            const placeholderLink = body.querySelector(selector);
            // Denis: if no placeholder is found, early return.
            if (!placeholderLink) {
                return;
            }
            // Denis: create a new element within the Document based on the provided selector.
            // The selector can be any native or custom web component (not an Angular component).
            // Keep in mind that the element will need to have a lowercase input prop for the reference.
            // We will attempt to create the element with the replaceElementSelector (local)
            // and fall back to the config.replaceElementSelector (global).
            const parsedLink = body.createElement(replaceElementSelector || this.config.replaceElementSelector);
            // Denis: because setAttribute expects a string value,
            // check if the provided routerLinkValue is an Array. If so, join it.
            const routerLinkValue = Array.isArray(link) ? link.join('/') : link;
            // Denis: set the link attribute of the component.
            // We will attempt to set the attribute with the linkAttributeName (local)
            // and fall back to the config.linkAttributeName (global).
            parsedLink.setAttribute(toAttribute || this.config.linkAttributeName, routerLinkValue);
            // Denis: copy the innerText of the placeholder element to the new element.
            parsedLink.innerText = placeholderLink.innerText;
            // Denis: replace the placeholder with the new element within the Document.
            placeholderLink.replaceWith(parsedLink);
        });
        // Denis: sanitize the document and mark it as trusted HTML before returning it to the template.
        return this.sanitizer.bypassSecurityTrustHtml(body.documentElement.innerHTML);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: WithRouterLinkPipe, deps: [{ token: WITH_ROUTER_LINKS_CONFIG }, { token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: WithRouterLinkPipe, name: "withRouterLinks" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: WithRouterLinkPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'withRouterLinks',
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [WITH_ROUTER_LINKS_CONFIG]
                }] }, { type: i1.DomSanitizer }] });

class UniqByPipe {
    transform(value, key) {
        if (!Array.isArray(value) || value.length === 0) {
            return [];
        }
        return uniqBy(value, key);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: UniqByPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: UniqByPipe, name: "uniqBy" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: UniqByPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'uniqBy',
                }]
        }] });

class LogPipe {
    /**
     * Logs the provided value to the console.
     *
     * @param value The value to log to the console.
     * @param text An optional textual value to print before the piped value.
     */
    transform(value, text) {
        Boolean(text) ? console.log(text, value) : console.log(value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: LogPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: LogPipe, name: "log" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: LogPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'log',
                }]
        }] });

const Pipes = [
    BtwPipe,
    CleanArrayPipe,
    EntriesPipe,
    HasObserversPipe,
    HasValuesPipe,
    HighlightPipe,
    IbanPipe,
    JoinPipe,
    LimitToPipe,
    SafeHtmlPipe,
    StripHtmlPipe,
    TransformPipe,
    TruncateTextPipe,
    UniqByPipe,
    WithRouterLinkPipe,
    CleanArrayPipe,
    LogPipe,
];

class UtilsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: UtilsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.0.4", ngImport: i0, type: UtilsModule, declarations: [BtwPipe, CleanArrayPipe, EntriesPipe, HasObserversPipe, HasValuesPipe, HighlightPipe, IbanPipe, JoinPipe, LimitToPipe, SafeHtmlPipe, StripHtmlPipe, TransformPipe, TruncateTextPipe, UniqByPipe, WithRouterLinkPipe, CleanArrayPipe, LogPipe, FocusClickDirective], exports: [BtwPipe, CleanArrayPipe, EntriesPipe, HasObserversPipe, HasValuesPipe, HighlightPipe, IbanPipe, JoinPipe, LimitToPipe, SafeHtmlPipe, StripHtmlPipe, TransformPipe, TruncateTextPipe, UniqByPipe, WithRouterLinkPipe, CleanArrayPipe, LogPipe, FocusClickDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: UtilsModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.4", ngImport: i0, type: UtilsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [Pipes, Directives],
                    exports: [Pipes, Directives],
                }]
        }] });

/*
 * Public API Surface of utils
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BtwPipe, CleanArrayPipe, Directives, EntriesPipe, FocusClickDirective, HasObserversPipe, HasValuesPipe, HighlightPipe, IbanPipe, JoinPipe, LimitToPipe, LogPipe, Pipes, SafeHtmlPipe, StripHtmlPipe, SubscriptionService, TransformPipe, TruncateTextPipe, UniqByPipe, UtilsModule, WITH_ROUTER_LINKS_CONFIG, WindowService, WithRouterLinkPipe, getQueryParams, windowMock, windowServiceMock };
//# sourceMappingURL=studiohyperdrive-ngx-utils.mjs.map
